@@ -52,7 +52,6 @@ class MovePlayer(game.ChessPlayer):
 class HumanPlayer(game.ChessPlayer):
     """
     """    
-    __game = None
     
     def __init__(self, chessGame, name):
         """Constructor.
@@ -74,11 +73,9 @@ class AIPlayer(ai.Player):
     def __init__(self, application, name, profile, level, description):
         """
         """
-        executable = profile.path
-        for arg in profile.arguments[1:]:
-            executable += ' ' + arg
-        self.window = application.ui.controller.addLogWindow(profile.name, executable, description)
         ai.Player.__init__(self, name, profile, level)
+        self.window = application.ui.controller.addLogWindow(profile.name, ' '.join(self.arguments), description)
+        self.start()
         
     def logText(self, text, style):
         """Called by ai.Player"""
